﻿using System;
using System.IO;
using System.Collections;

using Newtonsoft.Json.Linq;
using Tweetinvi;
using Tweetinvi.Credentials;
using Tweetinvi.Models;

using socialMedia.Class;

namespace socialMedia
{
	class MainClass
	{
		public static void Main(string[] args)
		{
			JObject properties = JObject.Parse(File.ReadAllText(@"../../Resources/properties.json")); //Get the properties to be used in the project

			MessageHandler messageHandler = new MessageHandler(properties.GetValue("llkAppKey").ToString(), properties.GetValue("llkAppSecret").ToString(), properties.GetValue("defaultOrigin").ToString()); //Initialize the message handler
			var userToken = properties.GetValue("user");
			long userId = (long)userToken["userId"];//Get Twitter userId
			JArray phoneNumbers = (JArray)userToken["phoneNumbers"];//Get the array/list of phoneNumbers which are going to be notified.

			//Set the credentials from your Twitter app
			Auth.SetUserCredentials(properties.GetValue("consumerKey").ToString(), properties.GetValue("consumerSecret").ToString(), properties.GetValue("token").ToString(), properties.GetValue("tokenSecret").ToString());

			var user = User.GetUserFromId(userId);//Get the user using the userId provided
			var stream = Tweetinvi.Stream.CreateUserStream();//Create a stream to start listening the user's activity
			stream.TweetCreatedByMe += (object sender, Tweetinvi.Events.TweetReceivedEventArgs tweetArgs) => {
				String tweetMessage = tweetArgs.Tweet.FullText; //Get the tweet text
				for (Int32 i = 0; i < phoneNumbers.Count; i++) {
					messageHandler.sendMessage(tweetMessage, phoneNumbers[i].ToString());//Sends a message with the tweet to the desired phoneNumbers
				}
				Console.WriteLine(user.Name + ": " + tweetMessage + " @ " + tweetArgs.Tweet.CreatedAt.ToString("f"));
			};
			stream.StartStream();//Start the stream so it will start monitoring the user's activity
		}
	}
}
